@@ -11,7 +11,7 @@ with 'PDK::Device::Base';
 # 定义登录成功提示符
 sub prompt {
   shift;
-  return '(\<(?:[^\<\>]*)\>)|(\[(?<!SubSlot \d)\])';
+  return '(\<.*?\>)|(\[(?<!SubSlot)\])';
 }
 
 # 定义特权模式提示符
@@ -40,21 +40,21 @@ sub waitfor {
       }
     ],
     [
-      qr/Are\s+you\s+sure\?\s*\[Y\/N\].*$/mi => sub {
+      qr/configuration will be written to the device. Are you sure.*$/mi => sub {
         $exp->send("Y\n");
         $buff .= $exp->before() . $exp->match();
         exp_continue;
       }
     ],
     [
-      qr/overwrite\?\s*\[Y\/N\].*$/mi => sub {
+      qr/startup.cfg exists, overwrite\?.*$/mi => sub {
         $exp->send("Y\n");
         $buff .= $exp->before() . $exp->match();
         exp_continue;
       }
     ],
     [
-      qr/press the enter key\).*$/mi => sub {
+      qr/press the enter key.*$/mi => sub {
         $exp->send("\r");
         $buff .= $exp->before() . $exp->match();
         exp_continue;
@@ -65,10 +65,12 @@ sub waitfor {
 
   # 如果发生异常，抛出错误
   if (defined $ret[1]) {
-    croak($ret[3]);
+    croak($ret[3] . $ret[1]);
   }
 
   # 修正脚本输出
+  # 这正则表达式的用途是匹配并删除输入字符串中的回车符（Carriage Return，\cM）以及紧随其后的零个或多个空格字符。
+  # 这种替换通常用于处理文本中的换行符和空格，使文本更规范化，去除多余的回车和空格。
   $buff =~ s/\cM+[ ]*\cM*//g;
 
   return $buff;
@@ -100,10 +102,13 @@ sub execCommands {
     $self->send("$cmd\n");
     my $buff = $self->waitfor();
 
-    if ($buff =~ /(% Ambiguous|% Incomplete|invalid|unrecognized)/i) {
+    if ($buff =~ /(% Ambiguous|% Incomplete|invalid|unrecognized).*$/i) {
       return {success => 0, failCommand => $cmd, reason => $result . $buff};
     }
-    elsif ($buff =~ /(%Error )|(^error: )/i) {
+    elsif ($buff =~ /((% Too many parameters)|(% Wrong parameter)).*$/i) {
+      return {success => 0, failCommand => $cmd, reason => $result . $buff};
+    }
+    elsif ($buff =~ /(%\s*Error )|(^error: )/i) {
       return {success => 0, failCommand => $cmd, reason => $result . $buff};
     }
     elsif ($buff =~ /(failed to pass the authorization)|(^\s*\^')/i) {
