@@ -27,15 +27,29 @@ sub waitfor {
   my @ret = $exp->expect(
     10,
     [
-      qr/^ --More-- /mi => sub {
+      qr/^ --More-- .*$/mi => sub {
         $exp->send(" ");
         $buff .= $exp->before();
         exp_continue;
       }
     ],
+    [
+      qr/Save configuration for/mi => sub {
+        $exp->send("y\r");
+        $buff .= $exp->before() . $exp->match();
+        exp_continue;
+      }
+    ],
+    [
+      qr/Backup all start configuration/mi => sub {
+        $exp->send("y\r");
+        $buff .= $exp->before() . $exp->match();
+        exp_continue;
+      }
+    ],
     [
       qr/are you sure/mi => sub {
-        $exp->send("Y\r");
+        $exp->send("y\r");
         $buff .= $exp->before() . $exp->match();
         exp_continue;
       }
@@ -45,7 +59,7 @@ sub waitfor {
 
   # 如果发生异常，抛出错误
   if (defined $ret[1]) {
-    croak($ret[3]);
+    croak($ret[3] . $ret[1]);
   }
 
   # 字符串修正处理
@@ -81,19 +95,19 @@ sub execCommands {
     $self->send("$cmd\n");
     my $buff = $self->waitfor();
 
-    if ($buff =~ /^\s+\^-----/i) {
+    if ($buff =~ /(incomplete command|ambiguous keyword|unrecognized keyword)/i) {
       return {success => 0, failCommand => $cmd, reason => $result . $buff};
     }
     elsif ($buff =~ /^Error:/i) {
       return {success => 0, failCommand => $cmd, reason => $result . $buff};
     }
-    elsif ($buff =~ /syntax error, expecting/i) {
+    elsif ($buff =~ /(syntax error, expecting|unknown command)/i) {
       return {success => 0, failCommand => $cmd, reason => $result . $buff};
     }
     elsif ($buff =~ /missing argument/i) {
       return {success => 0, failCommand => $cmd, reason => $result . $buff};
     }
-    elsif ($buff =~ /unknown command/i) {
+    elsif ($buff =~ /\s+\^-----.*$/i) {
       return {success => 0, failCommand => $cmd, reason => $result . $buff};
     }
     else {
