@@ -47,6 +47,13 @@ sub waitfor {
         exp_continue;
       }
     ],
+    [
+      qr/Do you want to save your changes\?.*$/mi => sub {
+        $exp->send("y\r");
+        $buff .= $exp->before() . $exp->match();
+        exp_continue;
+      }
+    ],
     [
       qr/Enter passphrase for key/mi => sub {
         $exp->send("186XXX\r");
@@ -59,7 +66,7 @@ sub waitfor {
 
   # 如果发生异常，抛出错误
   if (defined $ret[1]) {
-    croak($ret[3]);
+    croak($ret[3] . $ret[1]);
   }
 
   # 字符串修正处理
@@ -97,19 +104,19 @@ sub execCommands {
     $self->send("$cmd\n");
     my $buff = $self->waitfor();
 
-    if ($buff =~ /^\s+\^-----/i) {
+    if ($buff =~ /Error: .*$/i) {
       return {success => 0, failCommand => $cmd, reason => $result . $buff};
     }
-    elsif ($buff =~ /% Incomplete command/i) {
+    elsif ($buff =~ /Command not found/i) {
       return {success => 0, failCommand => $cmd, reason => $result . $buff};
     }
-    elsif ($buff =~ /% Ambiguous command/i) {
+    elsif ($buff =~ /Invalid parameter/i) {
       return {success => 0, failCommand => $cmd, reason => $result . $buff};
     }
-    elsif ($buff =~ /% Permission denied/i) {
+    elsif ($buff =~ /Permission denied/i) {
       return {success => 0, failCommand => $cmd, reason => $result . $buff};
     }
-    elsif ($buff =~ /Invalid input detected|Incomplete command/i) {
+    elsif ($buff =~ /(Command incomplete|Configuration error)/i) {
       return {success => 0, failCommand => $cmd, reason => $result . $buff};
     }
     else {
